/*
    Created by Quo
*/
 


-- UNIT MOVEMENT (ROCKETBOOTS)
-- Give every unit 1 additional move point
UPDATE Units SET BaseMoves=BaseMoves + 1 ;



-- TILES

-- OASIS
-- Make the area adjacent to an Oasis worth settling, can result in some amazing locations if you get lucky
INSERT INTO Feature_AdjacentYields (FeatureType, YieldType, YieldChange) VALUES ('FEATURE_OASIS', 'YIELD_FOOD', '2') ;
INSERT INTO Feature_AdjacentYields (FeatureType, YieldType, YieldChange) VALUES ('FEATURE_OASIS', 'YIELD_GOLD', '1') ;


-- Make the Oasis appear in Tundra! Why not?
INSERT INTO Feature_ValidTerrains 
	(FeatureType,		TerrainType)
VALUES	('FEATURE_OASIS',	'TERRAIN_TUNDRA') ;


-- FISHING BOATS
-- Add 1 gold
UPDATE Improvement_YieldChanges SET YieldChange='1' WHERE ImprovementType='IMPROVEMENT_FISHING_BOATS' AND YieldType='YIELD_GOLD' ;


-- SEA RESOURCES
-- Add 1 to the respective yield of each sea resource
UPDATE Resource_YieldChanges SET YieldChange='2' WHERE ResourceType ='RESOURCE_FISH' AND YieldType='YIELD_FOOD' ;
UPDATE Resource_YieldChanges SET YieldChange='2' WHERE ResourceType ='RESOURCE_PEARLS' AND YieldType='YIELD_FAITH' ;
INSERT INTO Resource_YieldChanges (ResourceType, YieldType, YieldChange) VALUES ('RESOURCE_WHALES', 'YIELD_FAITH', '1') ;
INSERT INTO Resource_YieldChanges (ResourceType, YieldType, YieldChange) VALUES ('RESOURCE_CRABS', 'YIELD_CULTURE', '1') ;


-- FANTASY RESOURCES
-- Make some additional resources available on the coast. These are somewhat far-fetched, but may assist with balancing the game.
INSERT INTO Resource_ValidTerrains
	(ResourceType,		TerrainType)
VALUES	('RESOURCE_MERCURY',	'TERRAIN_COAST') ,
	('RESOURCE_URANIUM',	'TERRAIN_COAST') , 
	('RESOURCE_SALT',	'TERRAIN_COAST') ;


-- ICE
-- Remove Ice completely from the map, to make sure the globe can be circled with boats
DELETE FROM Feature_ValidTerrains WHERE FeatureType='FEATURE_ICE' ;





-- BORDER EXPANSION RATE
-- Make borders pop faster
-- To make borders pop faster, give the Palace a global bonus to border expansion

INSERT INTO Modifiers
	(ModifierID, 			ModifierType, 					RunOnce, 	Permanent, 	OwnerRequirementSetId, 	SubjectRequirementSetId)
VALUES	('QUO_CULTURE_BORDER_DISCOUNT', 'MODIFIER_ALL_CITIES_CULTURE_BORDER_EXPANSION', 0, 		0, 		NULL,			NULL) ;


INSERT INTO ModifierArguments
	(ModifierID,			Name,		Type, 			Value,	Extra)
VALUES	('QUO_CULTURE_BORDER_DISCOUNT', 'Amount', 	'ARGTYPE_IDENTITY', 	'50',	NULL) ;


INSERT INTO BuildingModifiers
	(BuildingType,		ModifierID)
VALUES	('BUILDING_PALACE', 	'QUO_CULTURE_BORDER_DISCOUNT') ;



  

-- GOVERNMENT

-- Chiefdom 
-- Remove the economic policy slot and add a wildcard slot
UPDATE Government_SlotCounts SET NumSlots=0 WHERE GovernmentType='GOVERNMENT_CHIEFDOM' AND GovernmentSlotType='SLOT_ECONOMIC' ;

INSERT INTO Government_SlotCounts 
		(GovernmentType, GovernmentSlotType, NumSlots)
VALUES 	('GOVERNMENT_CHIEFDOM', 'SLOT_WILDCARD', 1) ;




-- BUILDINGS

-- PRICE OF MONUMENTS
-- Because borders pop faster, the Monument is now a vital building. To balance with Rome, I cut the production cost of Monuments in half.
UPDATE Buildings SET Cost=Cost*0.5 WHERE BuildingType='BUILDING_MONUMENT' ;	


--PALACE
--The Palace has the effect of walls
UPDATE Buildings SET OuterDefenseHitPoints='40', OuterDefenseStrength='2' WHERE BuildingType='BUILDING_PALACE' ;





-- DISTRICTS

-- AQUEDUCT
-- Aqueducts/Baths provide Great Engineer points
INSERT INTO District_GreatPersonPoints 
	(DistrictType, 		GreatPersonClassType, 		PointsPerTurn)
VALUES	('DISTRICT_AQUEDUCT',	'GREAT_PERSON_CLASS_ENGINEER',	'1' ) ,
	('DISTRICT_BATH',	'GREAT_PERSON_CLASS_ENGINEER',	'1' ) ;





-- INDIVIDUAL UNITS


-- SUPPORT UNITS
-- Cut cost of Support units in half
UPDATE Units SET Cost=Cost*0.5 WHERE FormationClass='FORMATION_CLASS_SUPPORT' ;


-- SWORDSMEN
-- Make Swordsmen somewhat better compared to horse units
UPDATE Units SET Combat='40' WHERE UnitType='UNIT_SWORDSMAN' ;


-- MUSKETMEN
-- Musketmen no longer require Niter, because this destroys the AI
UPDATE Units SET StrategicResource=NULL WHERE UnitType='UNIT_MUSKETMAN' ;


-- SCOUTS
-- Scouts start at level 2 instead of level 1, and get +1 vision
UPDATE Units SET InitialLevel='2', BaseSightRange='3' WHERE UnitType='UNIT_SCOUT' ;


--SETTLER STEALING
-- Kill the Settler on contact
UPDATE Units SET CanRetreatWhenCaptured='1' WHERE UnitType='UNIT_SETTLER' ;





-- INDIVIDUAL CIVS


-- FRANCE

-- CHATEAU: Change pre-req civic to Drama and Poetry. +1 Housing. Tourism bonus now unlocks with Humanism.
UPDATE Improvements SET PrereqCivic='CIVIC_DRAMA_POETRY', Housing='1' WHERE ImprovementType='IMPROVEMENT_CHATEAU' ;

UPDATE Improvement_Tourism SET PREREQTECH=NULL, PREREQCIVIC='CIVIC_HUMANISM' WHERE ImprovementType='IMPROVEMENT_CHATEAU' ;


-- Update the tech that unlocks Spies
UPDATE RequirementArguments SET Value='TECH_WRITING' WHERE RequirementId='REQUIRES_TECHNOLOGY_CASTLES' ;


-- SPAIN

-- MISSION: Make this unlock earlier. Now buildable on forest or jungle. Science bonus now starts at 1 and improves by 1 at the respective tech
UPDATE Improvements SET PrereqCivic='CIVIC_THEOLOGY' WHERE ImprovementType='IMPROVEMENT_MISSION' ;

UPDATE Improvement_BonusYieldChanges SET BonusYieldChange='1' WHERE ImprovementType='IMPROVEMENT_MISSION' AND YieldType='YIELD_SCIENCE' ;
UPDATE Improvement_YieldChanges SET YieldChange='1' WHERE ImprovementType='IMPROVEMENT_MISSION' AND YieldType = 'YIELD_SCIENCE' ;


INSERT INTO Improvement_ValidFeatures
	(	ImprovementType, 	FeatureType)  	
VALUES	(	'IMPROVEMENT_MISSION', 	'FEATURE_FOREST') ,
	(	'IMPROVEMENT_MISSION',	'FEATURE_JUNGLE') ;


-- Give Spain a discount on Holy districts
INSERT INTO TraitModifiers
	(TraitType, 			ModifierID)
VALUES	('TRAIT_LEADER_EL_ESCORIAL',	'TRAIT_BOOST_HOLY_SITE_PRODUCTION') ;






-- ATTITUDES

-- Pedro
-- Lower his hatred for players with more Great People.
UPDATE ModifierArguments SET Value='-1' WHERE ModifierId='AGENDA_MODIFIER_LEADS_GREAT_PEOPLE' AND Name='InitialValue' ; 


-- Saladin (and Philip?)
-- Lower his hatred for rival religions.
UPDATE ModifierArguments SET Value='-3' WHERE ModifierId='AGENDA_MODIFIER_ENCROACHING_RELIGION' AND Name='InitialValue' ; 


-- Mvemba
-- Lower his anger over not receiving player's religion.
UPDATE ModifierArguments SET Value='-2' WHERE ModifierId='AGENDA_MODIFIER_RELIGION_NOT_RECEIVED' AND Name='InitialValue' ; 


-- Pericles
-- Lower his anger from competing with him for a city state.
UPDATE ModifierArguments SET Value='-2' WHERE ModifierId='AGENDA_MODIFIER_DELIAN_COMPETING_MINORS' AND Name='InitialValue' ; 


-- Make the extremes of the Exploration random agenda less ridiculous since player nearly always violates this
UPDATE ModifierArguments SET Value='-2' WHERE ModifierID= 'AGENDA_HIGH_EXPLORATION' AND Name='InitialValue' ;
UPDATE ModifierArguments SET Value='2' WHERE ModifierID= 'AGENDA_LOW_EXPLORATION' AND Name='InitialValue' ;


-- Lower anger from different governments for Ideologues 
UPDATE ModifierArguments SET Value='-2' WHERE ModifierID='AGENDA_DIFFERENT_GOVERNMENT' AND Name='InitialValue' ;


-- Lower all whining about troops near borders
UPDATE ModifierArguments SET Value='-1' WHERE ModifierID= 'STANDARD_DIPLOMATIC_NEAR_BORDER_WARNING' AND Name='ReductionValue' ;
UPDATE ModifierArguments SET Value='0' WHERE ModifierID= 'STANDARD_DIPLOMATIC_NEAR_BORDER_WARNING' AND Name='InitialValue' ;
UPDATE ModifierArguments SET Value='1' WHERE ModifierID= 'STANDARD_DIPLOMATIC_NEAR_BORDER_WARNING' AND Name='ReductionTurns' ;


-- Make first impressions decay faster
UPDATE ModifierArguments SET Value='-1' WHERE ModifierID= 'STANDARD_DIPLOMACY_RANDOM' AND Name='ReductionValue' ;
UPDATE ModifierArguments SET Value='5' WHERE ModifierID= 'STANDARD_DIPLOMACY_RANDOM' AND Name='ReductionTurns' ;


-- Make breaking a promise less punishing
UPDATE ModifierArguments SET Value='5' WHERE ModifierID= 'STANDARD_DIPLOMACY_RANDOM' AND Name='ReductionTurns' ;
UPDATE ModifierArguments SET Value='-1' WHERE ModifierID= 'STANDARD_DIPLOMACY_RANDOM' AND Name='ReductionValue' ;
UPDATE ModifierArguments SET Value='-2' WHERE ModifierID= 'STANDARD_DIPLOMACY_RANDOM' AND Name='ModifierPerTransgression' ;


-- Remove all bitching about rival governments until the final 3
-- Note that the line below zeroes out ALL intolerance, even from mods that add new governments
UPDATE Governments SET OtherGovernmentIntolerance='0' ; 

UPDATE Governments SET OtherGovernmentIntolerance='-5' WHERE GovernmentType='GOVERNMENT_FASCISM' ;
UPDATE Governments SET OtherGovernmentIntolerance='-6' WHERE GovernmentType='GOVERNMENT_COMMUNISM' ;
UPDATE Governments SET OtherGovernmentIntolerance='-3' WHERE GovernmentType='GOVERNMENT_DEMOCRACY' ;
